==> argoscuolanext-0.5.tar.gz: argoscuolanext-0.5/setup.py <==
# This file is a part of ArgoScuolaNext Python API
#
# Copyright (c) 2017 The ArgoScuolaNext Python API Authors (see AUTHORS)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


from distutils.core import setup
setup(
    name='argoscuolanext',
    packages=['argoscuolanext'],
    package_dir={'': 'src'},
    version='0.5',
    description='ArgoScuolaNext Python API',
    author='Gabriel Hearot',
    author_email='gabriel@hearot.it',
    url='https://github.com/hearot/ArgoScuolaNext-Python',
    download_url='https://github.com/hearot/ArgoScuolaNext-Python/archive/v0.5.tar.gz',
    keywords=['argoscuolanext', 'python', 'school' 'api', 'rest'],
    classifiers=[]
)

==> argoscuolanext-1.0.1.tar.gz: argoscuolanext-1.0.1/setup.py <==
# This file is a part of ArgoScuolaNext Python API
#
# Copyright (c) 2017 The ArgoScuolaNext Python API Authors (see AUTHORS)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


from distutils.core import setup
setup(
    name='argoscuolanext',
    packages=['argoscuolanext'],
    package_dir={'': 'src'},
    version='1.0.1',
    description='ArgoScuolaNext Python API',
    author='Gabriel Hearot',
    author_email='gabriel@hearot.it',
    url='https://github.com/hearot/ArgoScuolaNext-Python',
    download_url='https://github.com/hearot/ArgoScuolaNext-Python/archive/v1.0.1.tar.gz',
    keywords=['argoscuolanext', 'python', 'school' 'api', 'rest'],
    classifiers=[]
)
